@@ -366,6 +366,7 @@ and os_of_string os ver =
   | "ubuntu", "16.04" -> Ubuntu (ver, "xenial")
   | "ubuntu", "18.04" -> Ubuntu (ver, "bionic")
   | "ubuntu", "20.04" -> Ubuntu (ver, "focal")
+  | "ubuntu", "22.04" -> Ubuntu (ver, "jammy")
   | "fedora", ver -> Fedora (int_of_string ver)
   | "freebsd", ver -> let maj, min = parse_major_minor ver in FreeBSD (maj, min)
   | "windows", ver -> parse_windows_version ver
@@ -959,7 +960,7 @@ and make_boot_media os arch =
      Location (sprintf "http://download.eng.bos.redhat.com/released/rhel-6-7-8/rhel-8/RHEL-8/8.%d.0/BaseOS/%s/os" minor (string_of_arch arch))
 
   | RHEL (9, minor), arch ->
-     Location (sprintf "http://download.eng.bos.redhat.com/released/rhel-9/RHEL-9/9.%d.0/BaseOS/%s/os" minor (string_of_arch arch))
+     Location (sprintf "http://download.eng.bos.redhat.com/released/RHEL-9/9.%d.0/BaseOS/%s/os" minor (string_of_arch arch))
 
   | Ubuntu (_, dist), X86_64 ->
      Location (sprintf "http://archive.ubuntu.com/ubuntu/dists/%s/main/installer-amd64" dist)
@@ -1233,15 +1234,14 @@ and os_variant_of_os ?(for_fedora = false) os arch =
        sprintf "rhel7.%d" minor
     | RHEL (7, _), _ -> "rhel7.5" (* max version known in Fedora 29 *)
     | RHEL (8, _), _ -> "rhel8.5" (* max version known in Fedora 36 *)
+    | RHEL (9, _), _ -> "rhel9.0" (* max version known in Fedora 37 *)
     | RHEL (major, minor), _ ->
        sprintf "rhel%d.%d" major minor
 
     | Debian (ver, _), _ when ver <= 8 -> sprintf "debian%d" ver
     | Debian _, _ -> "debian8" (* max version known in Fedora 26 *)
 
-    | Ubuntu (ver, _), _ when ver < "20.04" -> sprintf "ubuntu%s" ver
-    | Ubuntu ("20.04", _), _ -> "ubuntu19.10"
-    | Ubuntu _, _ -> assert false
+    | Ubuntu (ver, _), _ -> sprintf "ubuntu%s" ver
 
     | FreeBSD (major, minor), _ -> sprintf "freebsd%d.%d" major minor
 
